import React, {FunctionComponent} from "react";
import {ButtonVariants} from "../util/DataVariants";

/**
 *
 * @returns {Button Props}
 * @author Thushara Dinishka
 */
export interface ButtonProps {
    /**
     * The text content of the button.
     */
    value: string;
    /**
     * The type of the button.
     * Default type is `button`.
     */
    type?: "submit" | "reset" | "button";
    /**
     * The variant to use.
     * Default variant is `info`.
     */
    variant?: ButtonVariants;
    /**
     * If `true`, only the border will be visible with a color and the background will be transparent.
     */
    bordered?: boolean;
}

/**
 *
 * @returns {Button}
 * @author Thushara Dinishka
 */
export const Button: FunctionComponent<ButtonProps> = (props) => {

    const {type, value, variant, bordered} = props;

    let background = "bg-teal-300";
    let border = "border-teal-300";
    let hover = "hover:border-teal-500 hover:bg-teal-500";

    switch (variant) {
        case ButtonVariants.info:
            break;
        case ButtonVariants.success:
            background = "bg-green-300";
            border = "border-green-300";
            hover = "hover:border-green-500 hover:bg-green-500";
            break;
        case ButtonVariants.danger:
            background = "bg-red-300";
            border = "border-red-300";
            hover = "hover:border-red-500 hover:bg-red-500";
            break;
    }

    if (bordered) {
        background = "bg-transparent";
    }

    const classes = `px-10 py-2 rounded-lg text-sm font-medium text-gray-800 hover:text-white focus:outline-none border-2 ${background} ${border} ${hover}`;

    return (
        <button type={type} className={classes}>{value}</button>
    );
}

Button.defaultProps = {
    type: "button",
    variant: ButtonVariants.info,
    bordered: false
}
