import React, {FunctionComponent} from "react";
import {Button} from "./Button";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCircleNotch} from "@fortawesome/free-solid-svg-icons";
import {ButtonVariants} from "../util/DataVariants";

/**
 *
 * @returns {SubmitButton Props}
 * @author Thushara Dinishka
 */
export interface SubmitButtonProps {
    /**
     * Whether the form is currently submitting.
     */
    isSubmitting: boolean;
    /**
     * The text content of the button.
     */
    value: string;
    /**
     * The variant to use.
     * Default variant is `info`.
     */
    variant?: ButtonVariants;
}

/**
 *
 * @returns {SubmitButton}
 * @author Thushara Dinishka
 */
export const SubmitButton: FunctionComponent<SubmitButtonProps> = (props) => {

    const {isSubmitting, variant, value} = props;

    let background = "bg-teal-500";
    let border = "border-teal-500";

    switch (variant) {
        case ButtonVariants.info:
            break;
        case ButtonVariants.success:
            background = "bg-green-500";
            border = "border-green-500";
            break;
        case ButtonVariants.danger:
            background = "bg-red-500";
            border = "border-red-500";
            break;
    }

    const classes = `px-10 py-2 rounded-lg text-sm font-medium text-white focus:outline-none border-2 cursor-default ${background} ${border}`;

    if (isSubmitting) {
        return (
            <button className={classes} type="button">
                <FontAwesomeIcon icon={faCircleNotch} className="fa-spin"/> Loading
            </button>
        );
    } else {
        return <Button value={value} type="submit" variant={variant}/>
    }
}

SubmitButton.defaultProps = {
    variant: ButtonVariants.info
}
